﻿/*
 * CONTRIBUYEMTE
 * ====================================================================================================
 *
 * Descripción:
 *   Ejemplo que muesta como consumir el web service para obtener los datos de un contribuyente
 *
 * Datos requeridos:
 *   - RFC a consultar
 *   - ID CIF del RFC a consultar
 *
 * Datos retornados:
 *   - Nombre o razon social
 *   - Código postal
 *   - Régimen fiscal
 *   - Personas físicas (CURP, fecha de nacimiento, fecha de nacimiento, correo electrónico, etc)
 *   - Personas morales (fecha de constitución, correo electrónico, etc)
 */

using HyperSoft.Ejemplo.Utilerias;

namespace Facturando.Ejemplos.ValidarRfc
{
  class Program
  {
    static void Main(string[] args)
    {
      App.Initialization("Contribuyente");
      
      if (Integrador.Validate() == false)
        return;

      const string RfcConsultar = "";
      const string IdCif = "";

      if (string.IsNullOrEmpty(RfcConsultar) || string.IsNullOrEmpty(IdCif))
      {
        const string Message = "{0}Debes editar este archivo y asignar el RFC y el IDCIF a consultar (Línea 33-34){0}";
        Console.Write(Message);
        return;
      }

      string[,] parameters = {
        { "rfc", RfcConsultar },
        { "idcif", IdCif },

        // Datos de autentificación proporcionados por www.facturando.mx
        { "user", Integrador.User },
        { "iduser", Integrador.IdUser},

        // Congiuracion de la respuesta
        // Formato de la respuesta | Opcional | 1 - JSON
        { "result", "1"},
        // Dar formato a la respuesta | 0 - No / 1 - Si
        { "prettyprint", "1"},
      };

      Console.Write(new WebService("contribuyente.php").Send(parameters));
    }
  }
}
