{
 * CONTRIBUYEMTE
 * ====================================================================================================
 *
 * Descripcin:
 *   Ejemplo que muestra como consumir el web service para obtener los datos de un contribuyente
 *
 * Datos requeridos:
 *   - RFC a consultar
 *   - ID CIF del RFC a consultar
 *
 * Datos retornados:
 *   - Nombre o razn social
 *   - Cdigo postal
 *   - Rgimen fiscal
 *   - Personas fsicas (CURP, fecha de nacimiento, fecha de nacimiento, correo electrnico, etc.)
 *   - Personas morales (fecha de constitucin, correo electrnico, etc.)
 }

program Contribuyente;

{$APPTYPE CONSOLE}

uses
  SysUtils, Classes,
  HyperSoft.Ejemplo.Utilerias.Console in '..\Utils\HyperSoft.Ejemplo.Utilerias.Console.pas',
  HyperSoft.Ejemplo.Utilerias.Integrador in '..\Utils\HyperSoft.Ejemplo.Utilerias.Integrador.pas',
  HyperSoft.Ejemplo.Utilerias.WebService in '..\Utils\HyperSoft.Ejemplo.Utilerias.WebService.pas',
  uConsole in '..\Utils\uConsole.pas';

var
  rfcConsultar, idCif : string;
  parameters : TStringList;
  webService : TWebService;
  result : string;


begin
  TConsole.Instance.Init('Contribuyente');

  if (TIntegrador.Instance.Validate() = false) Then
    exit;

  rfcConsultar := '';
  idCif        := '';

  if ((rfcConsultar = EmptyStr) or (idCif = EmptyStr)) Then
    Begin
      TConsole.Instance.Write('{0}Debes editar este archivo y asignar el RFC y el IDCIF a consultar (Lnea 45-46){0}');
      exit;
    end;

  parameters := TStringList.Create();
  webService := TWebService.Create('contribuyente.php');
  try
    parameters.Values['rfc']   := rfcConsultar;
    parameters.Values['idcif'] := idCif;

    // Datos de autentificacin proporcionados por www.facturando.mx
    parameters.Values['user']    := TIntegrador.Instance.User;
    parameters.Values['iduser']  := TIntegrador.Instance.IdUser;

    // Congiuracion de la respuesta
    // Formato de la respuesta | Opcional | 1 - JSON
    parameters.Values['result'] := '1';

    // Dar formato a la respuesta | 0 - No / 1 - Si
    parameters.Values['prettyprint'] := '1';

    // Realizamos la consulta al web service pasandole los parmetros
    result := webService.Send(parameters);

    // Mostramos el resultado de la conssulta en pantalla
    TConsole.Instance.Write(result);
  finally
    FreeAndNil(webService);
    FreeAndNil(parameters);
  end;

end.
