{
 * CURP
 * ================================================================================
 *
 * Descripcin:
 *   Ejemplo que muestra como consumir el web service para obtener los datos de una 
 *   persona fisica a travs de la CURP
 *
 * Datos requeridos:
 *   - CURP
 *
 * Datos retornados:
 *   - RFC
 *   - Nombre completo (Nombre | Primer apellido | Segundo apellido)
 *   - Genero
 *   - Fecha de nacimiento
 *   - etc
 }

program Curp;

{$APPTYPE CONSOLE}

uses
  SysUtils, Classes, 
  HyperSoft.Ejemplo.Utilerias.Console in '..\Utils\HyperSoft.Ejemplo.Utilerias.Console.pas',
  HyperSoft.Ejemplo.Utilerias.Integrador in '..\Utils\HyperSoft.Ejemplo.Utilerias.Integrador.pas',
  HyperSoft.Ejemplo.Utilerias.WebService in '..\Utils\HyperSoft.Ejemplo.Utilerias.WebService.pas',
  uConsole in '..\Utils\uConsole.pas';

var
  curpValue : string;
  parameters : TStringList;
  webService : TWebService;
  result : string;

begin
  TConsole.Instance.Init('CURP');

  if (TIntegrador.Instance.Validate() = false) Then
    exit;

  curpValue := '';

  if (curpValue = EmptyStr) Then
    Begin
      TConsole.Instance.Write('{0}Debes editar este archivo y asignar la CURP a consultar (Lnea 43){0}');
      exit;
    end;

  parameters := TStringList.Create();
  webService := TWebService.Create('curp.php');
  try
    parameters.Values['data'] := curpValue;

    // Datos de autentificacin proporcionados por www.facturando.mx
    parameters.Values['user']    := TIntegrador.Instance.User;
    parameters.Values['iduser']  := TIntegrador.Instance.IdUser;

    // Congiuracion de la respuesta
    // Formato de la respuesta | Opcional | 1 - JSON
    parameters.Values['result'] := '1';

    // Dar formato a la respuesta | 0 - No / 1 - Si
    parameters.Values['prettyprint'] := '1';

    // Realizamos la consulta al web service pasandole los parmetros
    result := webService.Send(parameters);

    // Mostramos el resultado de la conssulta en pantalla
    TConsole.Instance.Write(result);
  finally
    FreeAndNil(webService);
    FreeAndNil(parameters);
  end;
end.
