{
 * VALIDAR CONTRIBUYENTE
 * ================================================================================
 *
 * Descripcin:
 *   Ejemplo que muestra como consumir el web service para verificar los datos de un
 *   contribuyente (CFDI 4.0)
 *
 * Datos requeridos:
 *   - RFC
 *   - Nombre
 *   - Cdigo postal
 *
 * Datos retornados:
 *   *  0 -> El dato no es vlido
 *   *  1 -> El dato es vlido
 *   * -1 -> El dato no pudo se validado
 }

program Validar_Contribuyente;

{$APPTYPE CONSOLE}

uses
  SysUtils, Classes, 
  HyperSoft.Ejemplo.Utilerias.Console in '..\Utils\HyperSoft.Ejemplo.Utilerias.Console.pas',
  HyperSoft.Ejemplo.Utilerias.Integrador in '..\Utils\HyperSoft.Ejemplo.Utilerias.Integrador.pas',
  HyperSoft.Ejemplo.Utilerias.WebService in '..\Utils\HyperSoft.Ejemplo.Utilerias.WebService.pas',
  uConsole in '..\Utils\uConsole.pas';

var
  rfcConsultar, nombre, codigoPostal : string;
  parameters : TStringList;
  webService : TWebService;
  result : string;

begin
  TConsole.Instance.Init('Validar contribuyente');

  // Verificamos si los datos del integrador han sido proporcionados
  if (TIntegrador.Instance.Validate() = false) Then
    exit;

  rfcConsultar := '';
  nombre       := '';
  codigoPostal := '';

  if ((rfcConsultar = EmptyStr) or (nombre = EmptyStr) or (codigoPostal = EmptyStr))Then
    Begin
      TConsole.Instance.Write('{0}Debes editar este archivo y asignar el RFC, nombre y cdigo postal{0}del contribuyente consultar (Lnea 44-46){0}');
      exit;
    end;

  parameters := TStringList.Create();
  webService := TWebService.Create('validarcontribuyente.php');
  try
    parameters.Values['rfc'] := rfcConsultar;
    parameters.Values['nombre'] := nombre;
    parameters.Values['cp'] := codigoPostal;

    // Datos de autentificacin proporcionados por www.facturando.mx
    parameters.Values['user']    := TIntegrador.Instance.User;
    parameters.Values['iduser']  := TIntegrador.Instance.IdUser;

    // Congiuracion de la respuesta
    // Formato de la respuesta | Opcional | 1 - JSON
    parameters.Values['result'] := '1';

    // Dar formato a la respuesta | 0 - No / 1 - Si
    parameters.Values['prettyprint'] := '1';

    // Realizamos la consulta al web service pasandole los parmetros
    result := webService.Send(parameters);

    // Mostramos el resultado de la conssulta en pantalla
    TConsole.Instance.Write(result);
  finally
    FreeAndNil(webService);
    FreeAndNil(parameters);
  end;
end.
