<?php

/*
 * VALIDAR CONTRIBUYENTE
 * ================================================================================
 *
 * Descripción:
 *   Ejemplo que muesta como consumir el web service para verificar los datos de un
 *   contribuyente (CFDI 4.0)
 *
 * Datos requeridos:
 *   - RFC
 *   - Nombre
 *   - Código postal
 *
 * Datos retornados:
 *   *  0 -> El dato no es válido
 *   *  1 -> El dato es válido
 *   * -1 -> El dato no pudo se validado
 */

include './include/CurlFacturando.php';
include './include/Integrador.php';

$rfc = '';
$nombre = '';
$codigoPostal = '';

if (empty($rfc) || empty($nombre) || empty($codigoPostal)) {
    $message = PHP_EOL .
        "Debes editar este archivo y asignar el RFC, nombre y código postal ".
        "del contribuyente consultar (Línea 25 - 27)" . PHP_EOL;
    exit($message);
}

$curl = new CurlFacturando('validarcontribuyente.php');

try {
    $params = [
        // RFC a consultar
        'rfc' => $rfc,
        'nombre' => $nombre,
        'cp' => $codigoPostal,

        // Datos de autentificación proporcionados por www.facturando.mx
        'user' => $user,
        'iduser' => $iduser,

        // Congiuracion de la respuesta
        // Formato de la respuesta | Opcional | 1 - JSON
        'result' => 1,
        // Dar formato a la salida | 0 - No / 1 - Si
        'prettyprint' => 1
    ];

    echo $curl->execute($params);
} catch (Exception $e) {
    $message = sprintf('Se generó un error al consumir el web service (%d | %s)', $e->getMessage(), $e->getCode());
    exit($message);
}